summaryrefslogtreecommitdiff
path: root/gui/Config.c
diff options
context:
space:
mode:
authorSND\edgbla_cp <SND\edgbla_cp@e17a0e51-4ae3-4d35-97c3-1a29b211df97>2011-06-08 09:27:25 +0000
committerSND\edgbla_cp <SND\edgbla_cp@e17a0e51-4ae3-4d35-97c3-1a29b211df97>2011-06-08 09:27:25 +0000
commit5f868fa161d5827e45a060a0b17b44a997625315 (patch)
tree1694ae3dfcb0189abdf098edbf6dae0bf2a18e4d /gui/Config.c
parentc7eb23ccf1813fb4ca47c309c40baff308151237 (diff)
downloadpcsxr-5f868fa161d5827e45a060a0b17b44a997625315.tar.gz
Rebranding.
git-svn-id: https://pcsxr.svn.codeplex.com/svn/pcsxr@67621 e17a0e51-4ae3-4d35-97c3-1a29b211df97
Diffstat (limited to 'gui/Config.c')
-rw-r--r--gui/Config.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gui/Config.c b/gui/Config.c
index f4b71d81..86038729 100644
--- a/gui/Config.c
+++ b/gui/Config.c
@@ -82,13 +82,13 @@ int LoadConfig(PcsxConfig *Conf) {
// Ryan says: use dotdir, dotdir is GOOD
// No giant homedir names
strncpy(cfgfile, getenv("HOME"), 200);
- strcat(cfgfile, PCSX_DOT_DIR);
+ strcat(cfgfile, PCSXR_DOT_DIR);
// proceed to load the cfg file
// append its name
strcat(cfgfile, cfgfile_basename);
// file is now ~/.pcsx/pcsx.cfg (or whatever cfgfile_basename is)
if (stat(cfgfile, &buf) == -1) {
// the config file doesn't exist!
/* TODO Error checking? */
@@ -82,13 +82,13 @@ int LoadConfig(PcsxConfig *Conf) {
// append its name
strcat(cfgfile, cfgfile_basename);
- // file is now ~/.pcsx/pcsx.cfg (or whatever cfgfile_basename is)
+ // file is now ~/.pcsxr/pcsxr.cfg (or whatever cfgfile_basename is)
if (stat(cfgfile, &buf) == -1) {
// the config file doesn't exist!